# 人员组织权限设计

> #### 注：集团，岗位分类，部门分类使用code关联，id没有实际意义，其他表均以id进行关联
>
> #### 注：除了项目id为公司自行维护，其余id均为UUID

## 数据结构

### 1、集团 org_group

| 字段   | 字段名称 | 非空 | 备注                       |
| ------ | -------- | ---- | -------------------------- |
| id     | 主键     | Y    | 全局唯一                   |
| code   | 编码     | Y    | 全局唯一，生成后不允许更改 |
| name   | 名称     | Y    | 集团名称（租户的名称）     |
| remark | 备注     |      |                            |



### 2、公司 org_company

| 字段      | 字段名称       | 非空 | 备注                            |
| --------- | -------------- | ---- | ------------------------------- |
| id        | 主键           | Y    | 全局唯一，UUID无实际意义        |
| code      | 公司编码       |      |                                 |
| name      | 公司名称       |      |                                 |
| groupCode | 集团编码       | Y    |                                 |
| parentId  | 上级公司ID     | Y    | 若为顶级公司为0                 |
| projects  | 公司关联的项目 |      | 通用查询中withColumns中可用字段 |
| remark    | 备注           |      |                                 |



### 3、项目 org_project

| 字段      | 字段名称       | 非空 | 备注                            |
| --------- | -------------- | ---- | ------------------------------- |
| id        | 主键           | Y    | 全局唯一（公司维护）            |
| name      | 项目名称       | Y    |                                 |
| groupCode | 集团编码       | Y    |                                 |
| companies | 项目关联的公司 |      | 通用查询中withColumns中可用字段 |
| remark    | 备注           |      |                                 |



### 4、部门 org_dept

| 字段             | 字段名称                           | 非空 | 备注                     |
| ---------------- | ---------------------------------- | ---- | ------------------------ |
| id               | ID                                 | Y    | 全局唯一，UUID无实际意义 |
| deptClassifyCode | 部门分类编码                       | Y    |                          |
| code             | 部门编码                           |      |                          |
| name             | 名称                               | Y    |                          |
| parentId         | 上级部门ID                         | Y    | “0”表示顶级部门          |
| companyId        | 所属公司                           | Y    |                          |
| resourceFrom     | 部门来源,null或0-FM新建,1-新城同步 |      |                          |
| groupCode        | 所属集团编码                       | Y    |                          |
| manager          | 部门负责人                         |      |                          |
| remark           | 备注                               |      |                          |



### 5、人员账号 org_user

| 字段          | 字段名称                                             | 非空 | 备注                     |
| ------------- | ---------------------------------------------------- | ---- | ------------------------ |
| id            | ID                                                   | Y    | 全局唯一，UUID无实际意义 |
| name          | 姓名                                                 |      |                          |
| idNumber    | 员工编号                                             |      |                          |
| username      | 账号                                                 |      |                          |
| password      | 密码                                                 |      |                          |
| gender        | 性别                                                 |      | 引用数据字典             |
| headPortrait | 头像                                                 |      |                          |
| birthday      | 生日                                                 |      |                          |
| phone         | 手机号                                               |      |                          |
| mail          | 邮箱                                                 |      |                          |
| otherAccount | 第三方账号                                           |      |                          |
| userFrom    | 账号来源,0-FM账号,1-苏宁账号,2-万达账号,3-新城OA账号 |      |                          |
| groupCode   | 所属集团                                              | Y    | 集团编码                        |
| isAdmin      | 是否为PERSAGYADMIN,0-不是,1-是                       |      |                          |
| status        | 状态                                                 | Y    | 是否有效                 |
| companyIds | 根据公司查询人（优先级最高） |  |  |
| deptIds | 根据部门查人 |  | 通用查询中withColumns中可用字段 |
| staffLevel | 人员职级 |  |  |
| userType | 人员类型 |  |  |
| entryTime | 入职时间 |  |  |
| leaveTime | 离职时间 |  |  |



### 6、部门分类 org_dept_classify

| 字段      | 字段名称     | 非空 | 备注                     |
| --------- | ------------ | ---- | ------------------------ |
| id        | 主键         | Y    | 全局唯一，UUID无实际意义 |
| code      | 部门分类编码 | Y    | 全局唯一，关联字段       |
| name      | 名称         | Y    |                          |
| parentId  | 父级分类ID   |      |                          |
| groupCode | 所属集团编码 | Y    |                          |
| orderNum  | 排序         |      |                          |
| remark    | 备注         |      |                          |



### 7、岗位分类org_job_classify

| 字段      | 字段名称     | 非空 | 备注                     |
| --------- | ------------ | ---- | ------------------------ |
| id        | 主键         | Y    | 全局唯一，UUID无实际意义 |
| code      | 岗位分类编码 | Y    | 全局唯一，关联字段       |
| name      | 名称         | Y    |                          |
| groupCode | 所属集团编码 | Y    |                          |
| orderNum  | 排序         |      |                          |



### 8、岗位 org_job

| 字段            | 字段名称                           | 非空 | 备注                     |
| --------------- | ---------------------------------- | ---- | ------------------------ |
| id              | ID                                 | Y    | 全局唯一，UUID无实际意义 |
| code            | 岗位编码                           |      |                          |
| name            | 名称                               |      |                          |
| groupCode       | 所属集团编码                       | Y    |                          |
| userId          | 账号ID                             | Y    |                          |
| deptId          | 部门ID                             | Y    |                          |
| jobClassifyCode | 岗位分类code                       | Y    |                          |
| resourceFrom    | 部门来源,null或0-FM新建,1-新城同步 |      |                          |
| status          | 状态                               | Y    |                          |



### 9、应用org_application

| 字段        | 字段名称                                                     | 非空 | 备注                     |
| ----------- | ------------------------------------------------------------ | ---- | ------------------------ |
| id          | ID                                                           | Y    | 全局唯一，UUID无实际意义 |
| code        | 编码                                                         | Y    | 全局唯一                 |
| name        | 应用名称                                                     | Y    |                          |
| category    | 所属产品大类                                                 | Y    | 标识产品线，引用数据字典 |
| appOrder    | 排序                                                         | Y    |                          |
| menuIconKey | 菜单小图标                                                   |      |                          |
| iconKey     | 小图标的Key                                                  |      |                          |
| description | 描述标签                                                     |      |                          |
| objType     | 标签类型,<br />g1-默认分组,g2-自定义分组,g3-APP端默认分组,<br />g4-APP端自定义分组,g5-BIM默认分组,<br />g6-BIM自定义分组标签 |      | 引用数据字典             |



### 10、功能org_function

| 字段          | 字段名称                                                     | 非空 | 备注                     |
| ------------- | ------------------------------------------------------------ | ---- | ------------------------ |
| id            | ID                                                           | Y    | 全局唯一，UUID无实际意义 |
| code          | 编码                                                         | Y    | 全局唯一                 |
| name          | 功能名称                                                     | Y    |                          |
| type          | 功能类型                                                     |      | 从数据字典取             |
| parentId      | 父节点                                                       |      |                          |
| appId         | 所属应用                                                     | Y    | 应用编码                 |
| functionUrl   | 功能跳转URL                                                  |      |                          |
| icon          | 图标                                                         |      |                          |
| description   | 功能描述                                                     |      |                          |
| functionAlias | 功能别名,页面展示菜单时优先取该字段值,如果为空才取name字段的值 |      |                          |
| objType       | 对象类型,f2-PC端功能F,f3-APP端功能F                          |      |                          |
| funcOrder     | 排序                                                         | Y    |                          |



### 11、岗位分类与应用功能关系 org_job_classify_rel

| 字段            | 字段名称     | 非空 | 备注                     |
| --------------- | ------------ | ---- | ------------------------ |
| id              | ID           | Y    | 全局唯一，UUID无实际意义 |
| jobClassifyCode | 岗位分类code | Y    |                          |
| groupCode       | 所属集团编码 | Y    |                          |
| appId           | 应用id       |      |                          |
| functionId      | 功能id       |      |                          |

### 12、集团与应用关系

| 字段          | 字段名称 | 非空 | 备注                        |
| ------------- | -------- | ---- | --------------------------- |
| id            | UUID     | Y    |                             |
| groupCode     | 集团编码 | Y    |                             |
| appId         | 应用id   | Y    |                             |
| authorityType | 权限类型 |      | 权限类型(0-权限集,1-权限包) |

### 13、集团与功能关系

| 字段          | 字段名称 | 非空 | 备注                        |
| ------------- | -------- | ---- | --------------------------- |
| id            | UUID     | Y    |                             |
| groupCode     | 集团编码 | Y    |                             |
| functionId    | 功能id   | Y    |                             |
| authorityType | 权限类型 |      | 权限类型(0-权限集,1-权限包) |

